@@ -433,6 +433,8 @@ typedef struct OMWeatherApplet{
     AppletConfig	*config;
     gboolean		show_update_window;
     gboolean		iap_connected;
+    gboolean		iap_connected_gsm;
+    gboolean		iap_connected_wlan;
     gboolean		iap_connecting;
     gboolean            current_is_valid;
     glong		iap_connecting_timer;
@@ -456,7 +458,6 @@ typedef struct OMWeatherApplet{
     guint		alerts_tab_start_state;
     guint		alerts_tab_current_state;
     GSList		*buttons;
-    guint		flag_updating;
     gboolean		dbus_is_initialize;
     gboolean		gps_must_be_current;
     GtkListStore	*user_stations_list;
