@@ -2,8 +2,8 @@
 /*
  * This file is part of Other Maemo Weather(omweather)
  *
- * Copyright (C) 2006-2009 Vlad Vasiliev
- * Copyright (C) 2006-2009 Pavel Fialko
+ * Copyright (C) 2006-2010 Vlad Vasiliev
+ * Copyright (C) 2006-2010 Pavel Fialko
  * 	for the code
  *        
  * Copyright (C) 2008 Andrew Zhilin
@@ -175,6 +175,11 @@ download_html(void *user_data){
         break;
         case SECOND_PHASE:
             DEBUG_FUNCTION("Second phase");
+            #ifdef DEBUGCONNECT
+                app->phase = FOURTH_PHASE;
+                return TRUE;
+            #endif
+
             /* check connection status */
             if(app->iap_connected){
                 app->phase = FOURTH_PHASE;
